@@ -133,7 +133,11 @@ class Thread
       bzeros (vec_bzeros),
       dwis (vec_dwis),
       normalise (normalise_to_b0),
-      done (false) { }
+      done (false) { 
+        dwi.set (0,-1);
+        if (mask) mask->set (0,-1);
+      }
+
     ~Thread () { }
 
     void execute ();
@@ -635,6 +639,7 @@ EXECUTE {
 
   DWI::SH::CSDeconv::Common sdeconv_common (response, filter, DW_dirs, HR_dirs, lmax);
   sdeconv_common.lambda = lambda;
+  sdeconv_common.threshold = threshold;
 
   Image::Object& SH_obj (*argument[2].get_image (header));
   SH_obj.map();
