@@ -20,6 +20,7 @@
 
 */
 
+#include <zlib.h>
 #include <glibmm/stringutils.h>
 
 #include "file/nifti1.h"
@@ -28,6 +29,7 @@
 #include "image/format/list.h"
 #include "math/quaternion.h"
 
+
 namespace MR {
   namespace Image {
     namespace Format {
@@ -35,19 +37,22 @@ namespace MR {
 
       const gchar* FormatNIfTI = "NIfTI-1.1";
 
-
-
-
-
-
-
       bool NIfTI::read (Mapper& dmap, Header& H) const
       {
-        if (!Glib::str_has_suffix (H.name, ".nii")) return (false);
+        if (!(Glib::str_has_suffix (H.name, ".nii") || Glib::str_has_suffix (H.name, ".nii.gz"))) 
+          return (false);
+
+        File::MMap fmap;
+        String gzfilename;
+        if (Glib::str_has_suffix (H.name, ".gz")) {
+          gzfilename = H.name;
+          fmap.init (Mapper::gunzip (H.name, "nii"));
+        }
+        else 
+          fmap.init (H.name);
 
-        H.format = FormatNIfTI;
-        File::MMap fmap (H.name);
         fmap.map();
+        H.format = FormatNIfTI;
 
         const nifti_1_header* NH = (const nifti_1_header*) fmap.address();
 
@@ -174,7 +179,7 @@ namespace MR {
           M(0,1) /= H.axes.vox[1];
           M(1,1) /= H.axes.vox[1];
           M(2,1) /= H.axes.vox[1];
-          
+
           M(0,2) /= H.axes.vox[2];
           M(1,2) /= H.axes.vox[2];
           M(2,2) /= H.axes.vox[2];
@@ -197,15 +202,15 @@ namespace MR {
           M(1,0) = transform[3];
           M(1,1) = transform[4];
           M(1,2) = transform[5];
-          
+
           M(2,0) = transform[6];
           M(2,1) = transform[7];
           M(2,2) = transform[8];
-          
+
           M(0,3) = get<float32> (&NH->qoffset_x, is_BE);
           M(1,3) = get<float32> (&NH->qoffset_y, is_BE);
           M(2,3) = get<float32> (&NH->qoffset_z, is_BE);
-          
+
           M(3,0) = M(3,1) = M(3,2) = 0.0;
           M(3,3) = 1.0;
 
@@ -233,7 +238,7 @@ namespace MR {
         }
 
         fmap.unmap();
-        dmap.add (fmap, data_offset);
+        dmap.add_gz (fmap, gzfilename, data_offset);
 
         return (true);
       }
@@ -244,7 +249,7 @@ namespace MR {
 
       bool NIfTI::check (Header& H, int num_axes) const
       {
-        if (!Glib::str_has_suffix (H.name, ".nii")) return (false);
+        if (!(Glib::str_has_suffix (H.name, ".nii") || Glib::str_has_suffix (H.name, ".nii.gz"))) return (false);
         if (num_axes < 3) throw Exception ("cannot create NIfTI-1.1 image with less than 3 dimensions");
         if (num_axes > 8) throw Exception ("cannot create NIfTI-1.1 image with more than 8 dimensions");
 
@@ -280,7 +285,15 @@ namespace MR {
 
         guint msize = H.memory_footprint (H.ndim());
 
-        File::MMap fmap (H.name, 352 + msize);
+        File::MMap fmap;
+        String gzfilename;
+        if (Glib::str_has_suffix (H.name, ".gz")) {
+          gzfilename = H.name;
+          fmap.init (String(), 352 + msize, "nii");
+        }
+        else 
+          fmap.init (H.name, 352 + msize);
+
         fmap.map();
 
         nifti_1_header* NH = (nifti_1_header*) fmap.address();
@@ -301,6 +314,11 @@ namespace MR {
         for (gint i = 0; i < H.ndim(); i++) 
           put<gint16> (H.dim(i), &NH->dim[i+1], is_BE);
 
+        // pad out the other dimensions with 1, fix for fslview
+        for (gint i = H.ndim() + 1; i < 8; i++) 
+          put<gint16> (1, &NH->dim[i], is_BE);
+
+
         // data type:
         gint16 dt = 0;
         switch (H.data_type()) {
@@ -365,9 +383,9 @@ namespace MR {
 
         // qform:
         const float R [] = { 
-          M(0,0), M(0,1), M(0,2), 
-          M(1,0), M(1,1), M(1,2), 
-          M(2,0), M(2,1), M(2,2) };
+          float(M(0,0)), float(M(0,1)), float(M(0,2)), 
+          float(M(1,0)), float(M(1,1)), float(M(1,2)), 
+          float(M(2,0)), float(M(2,1)), float(M(2,2)) };
         const Math::Quaternion Q (R);
 
         put<float32> (Q[1], &NH->quatern_b, is_BE);
@@ -398,7 +416,7 @@ namespace MR {
         strncpy ((gchar*) &NH->magic, "n+1\0", 4);
         fmap.unmap();
 
-        dmap.add (fmap, 352);
+        dmap.add_gz (fmap, gzfilename, 352);
       }
 
     }
