@@ -39,9 +39,9 @@
 #define __mrview_sidebar_tractography_tracklist_item_h__
 
 #include <list>
-#include <GL/gl.h>
 #include <glib/gstdio.h>
 
+#include "use_gl.h"
 #include "ptr.h"
 #include "point.h"
 #include "math/vector.h"
@@ -194,8 +194,8 @@ namespace MR {
           void load (const String& filename);
           bool refresh ()
           {
-            struct stat S;
-            if (g_stat (file.c_str(), &S))
+            struct_stat64 S;
+            if (STAT64 (file.c_str(), &S))
               throw Exception ("error accessing tracks file \"" + file + "\": " + Glib::strerror (errno));
             if (mtime != S.st_mtime) { 
               load (file);
